/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Generates statistics about the share of leadership occupations that are the top earner at a firm by industry and firm size.

	OUTPUT DATASETS:
	- outputs.occtype_freq_top1_ind_rr
	- outputs.occtype_freq_top1_ind_rr_stat
	- outputs.occtype_freq_top1_ind3_rr
	- outputs.occtype_freq_top1_ind3_rr_stat
	- outputs.occtype_freq_top1_indsz_rr
*********************************************************************************************/


%let num_obs = max;

data tmp_for_freqs ;
    set interwrk.acs_occ_earn(obs=&num_obs.);
    
    industry_2d = substr(naics,1,2);
    industry_3d = substr(naics,1,3);
    industry_4d = substr(naics,1,4);

    occ_3d = substr(occ,1,3);
    
    
    if fq_earn_4qma_n < &p99_min_fsize. then is_p99_fq_earn = .;
    if fq_earn_4qma_n < &p95_min_fsize. then is_p95_fq_earn = .;
    if fq_earn_4qma_n < &p90_min_fsize. then is_p90_fq_earn = .;
    if fq_earn_4qma_n < &top3_min_fsize. then is_top3_fq_earn = .;
    if fq_earn_4qma_n < &top1_min_fsize. then is_top1_fq_earn = .;
    
    
    if firmsize <= 19 then do;
        fsz = "000to019";
        fsz_small = "<20";
    end;
    else if firmsize <= 49 then fsz = "020to049";
    else if firmsize <= 249 then fsz = "050to249";
    else if firmsize <= 499 then fsz = "250to499";
    else if firmsize > 500 then fsz = "500+";
    if firmsize > 19 then fsz_small = "20+";
    
    if fq_earn_4qma_n <= 19 then do;
        fsz_alt = "000to019";
        fsz_alt_small = "<20";
    end;
    else if fq_earn_4qma_n <= 49 then fsz_alt = "020to049";
    else if fq_earn_4qma_n <= 249 then fsz_alt = "050to249";
    else if fq_earn_4qma_n <= 499 then fsz_alt = "250to499";
    else if fq_earn_4qma_n > 500 then fsz_alt = "500+"; 
    if fq_earn_4qma_n > 19 then fsz_alt_small = "20+";

    
    if 0 <= firmage <= 1 then fage = "00to01";
    else if firmage <= 3 then fage = "02to03";
    else if firmage <= 5 then fage = "04to05";
    else if firmage <= 10 then fage = "06to10";
    else if firmage > 10 then fage = "11+";

    sein_state = substr(sein,1,2);
run;
    
PROC CONTENTS DATA=tmp_for_freqs;
RUN;

data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
    
proc freq data=tmp_for_freqs noprint ;
    *table occ_3d*sex / out=outputs.occ3_freq outpct;
    table occ_type*sex /out=outputs.occtype_freq outpct;
run;

proc print data=outputs.occtype_freq(where=(percent > 1.0));
    
    
    
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - top1 earner";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
    
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1)) noprint ;
    *table occ_3d*sex / out=outputs.occ3_freq_top1 outpct ;
    table occ_type*sex /out=outputs.occtype_freq_top1 outpct;
run;
    
proc print data=outputs.occtype_freq_top1(where=(percent > 1.0));

    
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1)) noprint ;
    weight fq_earn_4qma_n;
    *table occ_3d*sex / out=outputs.occ3_freq_top1 outpct ;
    table occ_type*sex /out=outputs.occtype_freq_top1_wt outpct;
run;


    
proc sort data=tmp_for_freqs;
    by fsz;
run;
/*
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - top1 earner by firm size";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1 and fsz ~= "")) noprint ;
    by fsz;
    table occ_3d*sex / out=outputs.occ3_freq_top1_fsz outpct  ;
    table occ_type*sex /out=outputs.occtype_freq_top1_fsz outpct;
run;

proc print data=outputs.occtype_freq_top1_fsz (where=(percent >1.0));
    */
proc sort data=tmp_for_freqs;
    by fsz;
run;

data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - top3 earner";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs (where=(is_top3_fq_earn=1)) noprint ;
    *table occ_3d*sex / out=outputs.occ3_freq_top3 outpct ;
    table occ_type*sex /out=outputs.occtype_freq_top3 outpct;
run;

proc print data=outputs.occtype_freq_top3 (where=(percent >1.0));

proc freq data=tmp_for_freqs (where=(is_top3_fq_earn=1)) noprint ;
    weight fq_earn_4qma_n;
    *table occ_3d*sex / out=outputs.occ3_freq_top3 outpct ;
    table occ_type*sex /out=outputs.occtype_freq_top3_wt outpct;
run;
/*
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - top3 earner by firm size";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs (where=(is_top3_fq_earn=1 and fsz ~= "")) noprint ;
    by fsz;
    table occ_3d*sex / out=outputs.occ3_freq_top3_fsz outpct  ;
    table occ_type*sex /out=outputs.occtype_freq_top3_fsz outpct;
run;

proc print data=outputs.occtype_freq_top3_fsz (where=(percent >1.0));
*/

proc freq data=tmp_for_freqs (where=(is_p99_fq_earn=1)) NOPRINT;
    *table occ_3d*sex / out=outputs.occ3_freq_p99 outpct ;
    table occ_type*sex / out=outputs.occtype_freq_p99 outpct ;
run;
    
proc freq data=tmp_for_freqs (where=(is_p99_fq_earn=1)) NOPRINT;
    weight fq_earn_4qma_n;
    *table occ_3d*sex / out=outputs.occ3_freq_p99 outpct ;
    table occ_type*sex / out=outputs.occtype_freq_p99_wt outpct ;
run;
    

proc freq data=tmp_for_freqs (where=(is_p95_fq_earn=1)) NOPRINT;
    *table occ_3d*sex / out=outputs.occ3_freq_p95 outpct ;
    table occ_type*sex / out=outputs.occtype_freq_p95 outpct ;
run;
    
proc freq data=tmp_for_freqs (where=(is_p95_fq_earn=1)) NOPRINT;
    weight fq_earn_4qma_n;
    *table occ_3d*sex / out=outputs.occ3_freq_p95 outpct ;
    table occ_type*sex / out=outputs.occtype_freq_p95_wt outpct ;
run;
    
    
/*
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - p95 earner by firm size";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs (where=(is_p95_fq_earn=1 and fsz ~= "")) noprint ;
    by fsz;
    table occ_3d*sex / out=outputs.occ3_freq_p95_fsz outpct  ;
    table occ_type*sex /out=outputs.occtype_freq_p95_fsz outpct;
run;

proc print data=outputs.occtype_freq_p95_fsz (where=(percent >1.0));
*/

proc sort data=tmp_for_freqs;
    by is_p90_fq_earn;
run;
proc freq data=tmp_for_freqs  NOPRINT ;
    by is_p90_fq_earn;
    *table occ_3d*sex / out=outputs.occ3_freq_p90 outpct;
    table occ_type*sex / out=outputs.occtype_freq_p90 outpct;
run;
    
proc freq data=tmp_for_freqs  NOPRINT ;
    by is_p90_fq_earn;
    weight fq_earn_4qma_n;
    *table occ_3d*sex / out=outputs.occ3_freq_p90 outpct;
    table occ_type*sex / out=outputs.occtype_freq_p90_wt outpct;
run;
    
    
/*
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - p90 earner by firm size";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs (where=(is_p90_fq_earn=1 and fsz ~= "")) noprint ;
    by fsz;
    table occ_3d*sex / out=outputs.occ3_freq_p90_fsz outpct ;
    table occ_type*sex /out=outputs.occtype_freq_p90_fsz outpct;
run;

proc print data=outputs.occtype_freq_p90_fsz (where=(percent >1.0));
*/


proc sort data=tmp_for_freqs;
    by fsz occ_type sex;
run;
    
proc freq data=tmp_for_freqs (where=((occ_type= "Exec or Manager" or occ_type="Professional" or occ_type = "Supervisor") and fq_earn_4qma_n >= 10));
    by fsz occ_type sex;
    
    table is_top1_fq_earn  /out=outputs.in_top1_freq_occ;
    table  is_top3_fq_earn  /out=outputs.in_top3_freq_occ;
    table  is_p99_fq_earn  /out=outputs.in_p99_freq_occ;
    table  is_p95_fq_earn  /out=outputs.in_p95_freq_occ;
    table  is_p90_fq_earn /out=outputs.in_p90_freq_occ;
 
run;

proc print data=outputs.in_top1_freq_occ;


*  state counts;

proc sort data=tmp_for_freqs
          out=tmp_for_freqs_sorted;
    by sein_state is_p90_fq_earn;
run;
    
proc freq data=tmp_for_freqs_sorted (where=(is_top1_fq_earn=1)) noprint;
    by sein_state;
    table occ_type*sex /out=outputs.occtype_freq_top1_stcnt outpct;
run;
  
proc freq data=tmp_for_freqs_sorted (where=(is_top3_fq_earn=1)) noprint;
    by sein_state;
    table occ_type*sex /out=outputs.occtype_freq_top3_stcnt outpct;
run;
  
proc freq data=tmp_for_freqs_sorted (where=(is_p99_fq_earn=1)) noprint;
    by sein_state;
    table occ_type*sex /out=outputs.occtype_freq_top1_stcnt outpct;
run;
  
proc freq data=tmp_for_freqs_sorted (where=(is_p95_fq_earn=1)) noprint;
    by sein_state;
    table occ_type*sex /out=outputs.occtype_freq_p95_stcnt outpct;
run;
  
proc freq data=tmp_for_freqs_sorted (where=(is_p90_fq_earn~=.)) noprint;
    by sein_state is_p90_fq_earn;
    table occ_type*sex /out=outputs.occtype_freq_p90_stcnt outpct;
run;
  

proc sort data=tmp_for_freqs
          out=tmp_for_freqs_sorted;
    by sein_state fsz occ_type sex;
run;
    
proc freq data=tmp_for_freqs_sorted (where=((occ_type= "Exec or Manager" or occ_type="Professional" or occ_type = "Supervisor") and fq_earn_4qma_n >= 10));
    by sein_state fsz occ_type sex;
    
    table  is_top3_fq_earn  /out=outputs.in_top3_freq_occ_stcnt;
 
run;




*******************************************************************;
*******************************************************************;
*******************************************************************;
*******************************************************************;
* Everything below this line is interesting for an occupation impute, but not important for our analysis;
*******************************************************************;
*******************************************************************;
*******************************************************************;

/*

proc sort data=tmp_for_freqs;
    by industry_3d fsz;
run;
    
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY 2-DIGIT INDUSTRY";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs noprint ;
    by industry_2d;
    table occ_3d / out=outputs.occ3_freq_ind2;
    table occ_type /out=outputs.occtype_freq_ind2;
run;
    
proc print data=outputs.occ3_freq_ind2 (where=(percent > 10.0));

    
  data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY 2-DIGIT INDUSTRY";
    PUT "     - top 1 earner ";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs(where=(is_top1_fq_earn=1)) noprint  ;
    by industry_2d;
    table occ_3d / out=outputs.occ3_freq_top1_ind2;
    table occ_type /out=outputs.occtype_freq_top1_ind2;
run;

proc print data=outputs.occtype_freq_top1_ind2 (where=(percent > 10.0));

     
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY 3-DIGIT INDUSTRY";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 


proc freq data=tmp_for_freqs noprint ;
    by industry_3d;
    table occ_3d / out=outputs.occ3_freq_ind3;
    table occ_type /out=outputs.occtype_freq_ind3;
run;

proc print data=outputs.occtype_freq_ind3 (where=(percent >10.0));
    
    
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY 3-DIGIT INDUSTRY";
    PUT "     - top 1 earner ";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs(where=(is_top1_fq_earn=1)) noprint  ;
    by industry_3d;
    table occ_3d / out=outputs.occ3_freq_top1_ind3;
    table occ_type /out=outputs.occtype_freq_top1_ind3;
run;

proc print data=outputs.occtype_freq_top1_ind3 (where=(percent >10.0));

    
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY 3-DIGIT INDUSTRY BY FIRM SIZE";
    PUT "     - top 1 earner ";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc sort data=tmp_for_freqs;
    by industry_3d fsz_small;
run;
    
proc freq data=tmp_for_freqs(where=(is_top1_fq_earn=1 and fsz_small ~= "")) noprint  ;
    by industry_3d fsz_small;
    table occ_3d / out=outputs.occ3_freq_top1_ind3_fsz;
    table occ_type /out=outputs.occtype_freq_top1_ind3_fsz;
run;

*proc print data=outputs.occ3_freq_top1_ind3_fsz (where=(percent >5.0));
proc print data=outputs.occtype_freq_top1_ind3_fsz (where=(percent >10.0));

proc sort data=tmp_for_freqs;
    by naics fsz_small;
run;

data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY NAICS INDUSTRY ";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs noprint  ;
    by naics ;
    table occ_type / out=outputs.occtype_freq_naics;
run;

proc print data=outputs.occtype_freq_naics (where=(percent >20.0));
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY NAICS INDUSTRY AND FIRM SIZE ";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc freq data=tmp_for_freqs noprint  ;
    by naics fsz_small;
    table occ_3d / out=outputs.occ3_freq_naics_fsz;
    table occ_type / out=outputs.occtype_freq_naics_fsz;
run;

proc print data=outputs.occtype_freq_naics_fsz (where=(percent >20.0));


data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION BY NAICS INDUSTRY AND ABOVE VS BELOW AVG FIRM EARNINGS ";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
proc sort data=tmp_for_freqs;
    by naics is_above_avg_fq_earn;
run;

proc freq data=tmp_for_freqs noprint  ;
    by naics is_above_avg_fq_earn;
    table occ_3d / out=outputs.occ3_freq_naics_gravgearn;
    table occ_type / out=outputs.occtype_freq_naics_gravgearn;
run;

proc print data=outputs.occtype_freq_naics_gravgearn (where=(percent >20.0));

/*

    
proc freq data=tmp_for_freqs NOPRINT;
    by industry_2d;
    table occ_3d*is_top1_fq_earn / out=outputs.occ3_freq_top1_ind2 outpct;
    table occ_3d*is_top3_fq_earn / out=outputs.occ3_freq_top3_ind2 outpct;
    table occ_3d*is_p99_fq_earn / out=outputs.occ3_freq_p99_ind2 outpct;
    table occ_3d*is_p95_fq_earn / out=outputs.occ3_freq_p95_ind2 outpct;
    table occ_3d*is_p90_fq_earn / out=outputs.occ3_freq_p90_ind2 outpct;
    table occ_3d / out=outputs.occ3_freq_ind2 ;
    table occ_3d*is_above_avg_fq_earn*occ_3d / out=outputs.occ3_freq_avg_ind2 outpct;
    table occ_3d*fsz / out=outputs.occ3_freq_fsz_ind2 outpct;
    table fsz*occ_3d*is_above_avg_fq_earn / out=outputs.occ3_freq_fsz_avg_ind2 outpct;
    table fsz*occ_3d*is_top1_fq_earn / out=outputs.occ3_freq_fsz_top1_ind2 outpct;
run;  
    
proc freq data=tmp_for_freqs NOPRINT;
    by industry_3d;
    table occ_3d*is_top1_fq_earn / out=outputs.occ3_freq_top1_ind3 outpct;
    table occ_3d*is_top3_fq_earn / out=outputs.occ3_freq_top3_ind3 outpct;
    table occ_3d*is_p99_fq_earn / out=outputs.occ3_freq_p99_ind3 outpct;
    table occ_3d*is_p95_fq_earn / out=outputs.occ3_freq_p95_ind3 outpct;
    table occ_3d*is_p90_fq_earn / out=outputs.occ3_freq_p90_ind3 outpct;
    table occ_3d / out=outputs.occ3_freq_ind3 ;
    table occ_3d*is_above_avg_fq_earn*occ_3d / out=outputs.occ3_freq_avg_ind3 outpct;
    table occ_3d*fsz /out=outputs.occ3_freq_fsz_ind3 outpct;
    table fsz*occ_3d*is_above_avg_fq_earn / out=outputs.occ3_freq_fsz_avg_ind3 outpct;
    table fsz*occ_3d*is_top1_fq_earn / out=outputs.occ3_freq_fsz_top1_ind3 outpct;
run;  
*/
