/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Generates statistics about the share of leadership occupations that are the top earner at a firm by industry and firm size.

	OUTPUT DATASETS:
	- outputs.occtype_freq_top1_ind_rr
	- outputs.occtype_freq_top1_ind_rr_stat
	- outputs.occtype_freq_top1_ind3_rr
	- outputs.occtype_freq_top1_ind3_rr_stat
	- outputs.occtype_freq_top1_indsz_rr

*********************************************************************************************/


%let num_obs = max;

data tmp_for_freqs ;
    set interwrk.acs_occ_earn(obs=&num_obs.);
    
    industry_2d = substr(naics,1,2);
    industry_3d = substr(naics,1,3);
    industry_4d = substr(naics,1,4);

    occ_3d = substr(occ,1,3);
    
    
    if fq_earn_4qma_n < &p99_min_fsize. then is_p99_fq_earn = .;
    if fq_earn_4qma_n < &p95_min_fsize. then is_p95_fq_earn = .;
    if fq_earn_4qma_n < &p90_min_fsize. then is_p90_fq_earn = .;
    if fq_earn_4qma_n < &top3_min_fsize. then is_top3_fq_earn = .;
    if fq_earn_4qma_n < &top1_min_fsize. then is_top1_fq_earn = .;
    
    
    if firmsize <= 19 then do;
        fsz = "000to019";
        fsz_small = "<20";
    end;
    else if firmsize <= 49 then fsz = "020to049";
    else if firmsize <= 249 then fsz = "050to249";
    else if firmsize <= 499 then fsz = "250to499";
    else if firmsize > 500 then fsz = "500+";
    if firmsize > 19 then fsz_small = "20+";
    
    large_firm=0;
    if fsz = "500+" then large_firm=1;

    if fq_earn_4qma_n <= 19 then do;
        fsz_alt = "000to019";
        fsz_alt_small = "<20";
    end;
    else if fq_earn_4qma_n <= 49 then fsz_alt = "020to049";
    else if fq_earn_4qma_n <= 249 then fsz_alt = "050to249";
    else if fq_earn_4qma_n <= 499 then fsz_alt = "250to499";
    else if fq_earn_4qma_n > 500 then fsz_alt = "500+"; 
    if fq_earn_4qma_n > 19 then fsz_alt_small = "20+";

    
    if 0 <= firmage <= 1 then fage = "00to01";
    else if firmage <= 3 then fage = "02to03";
    else if firmage <= 5 then fage = "04to05";
    else if firmage <= 10 then fage = "06to10";
    else if firmage > 10 then fage = "11+";

    sein_state = substr(sein,1,2);

    if occ_type="Exec or Manager" or occ_type="Professional" or occ_type="Supervisor" then is_mngr = 1;
    else is_mngr = 0;
run;
    
PROC CONTENTS DATA=tmp_for_freqs;
RUN;

data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 

    
    
data _null_;
    file print;
    put " ========================================================";
    put " ========================================================";
    put " 3-DIGIT OCCUPATION";
    PUT "     - top1 earner";
    put " ========================================================";
    put " ========================================================";
    file log;
run; 
    
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1)) noprint ;
    table is_mngr /out=tmp_occtype_freq_top1 outpct;
run;
    
proc print data=tmp_occtype_freq_top1(where=(percent > 1.0));

* 2 digit industry;
proc sort data=tmp_for_freqs;
    by industry_2d;
run; 
    
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1)) noprint ;
    by industry_2d;
    table is_mngr /out=outputs.occtype_freq_top1_ind_rr outpct;
run;
    
proc print data=outputs.occtype_freq_top1_ind_rr(where=(is_mngr=1));
proc contents data=outputs.occtype_freq_top1_ind_rr;

proc means data=outputs.occtype_freq_top1_ind_rr(where=(is_mngr=1));
    var percent;
    output out=outputs.occtype_freq_top1_ind_rr_stat mean= var= /autoname;
run;

* 3 digit industry; 
proc sort data=tmp_for_freqs;
    by industry_3d;
run; 
    
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1)) noprint ;
    by industry_3d;
    table is_mngr /out=outputs.occtype_freq_top1_ind3_rr outpct;
run;
    
proc print data=outputs.occtype_freq_top1_ind3_rr(where=(is_mngr=1));
proc contents data=outputs.occtype_freq_top1_ind3_rr;

proc means data=outputs.occtype_freq_top1_ind3_rr(where=(is_mngr=1));
    var percent;
    output out=outputs.occtype_freq_top1_ind3_rr_stat mean= var= /autoname;
run;


* 2 digit industry and firm size;
DATA temp(KEEP=industry_2d large_firm n is_mngr);
	SET tmp_for_freqs(where=(is_top1_fq_earn=1));
	n=1;
RUN;

proc sort data=temp;
    by industry_2d large_firm;
run; 

PROC MEANS DATA=temp NOPRINT;
	BY industry_2d large_firm;
	VAR n is_mngr;
	OUTPUT OUT=outputs.occtype_freq_top1_indsz_rr(KEEP=industry_2d large_firm n is_mngr)
		SUM(n)=n 
		SUM(is_mngr)=is_mngr;
RUN;

/*
proc sort data=tmp_for_freqs;
    by industry_2d large_firm;
run; 
    
proc freq data=tmp_for_freqs (where=(is_top1_fq_earn=1)) noprint ;
    by industry_2d large_firm;
    table is_mngr /out=outputs.occtype_freq_top1_indsz_rr output;
run;
    
proc print data=outputs.occtype_freq_top1_indsz_rr(where=(is_mngr=1));
proc contents data=outputs.occtype_freq_top1_indsz_rr;

proc means data=outputs.occtype_freq_top1_indsz_rr(where=(is_mngr=1));
    var percent;
    output out=outputs.occtype_freq_top1_indsz_rr mean= var= /autoname;
run;
*/
