*------------------------------------------------------------------------------------------*
*	CLEAN DATA FOR ANALYSIS
*------------------------------------------------------------------------------------------*

global outcomelist de3yr emp_at_samefid_yr* sepne2yr empft1yrlater de5yr dfqe
global covarlist birthyear educ_c ethnicity race naics marital_status ///
	firmsize lnfirmsize pre_lnearnings age sex tenure_bck birth_order ///
	top1_f_ratio top3_f_ratio p90_f_ratio p95_f_ratio p99_f_ratio birth_qtime ///
	firmage lnfirmsize
	
*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*------------------------------------------------------------------------------------------*
*	DEFINE PROGRAMS
*------------------------------------------------------------------------------------------*
{
*generate outcome variables
	*de3yr=ihs(total earings three years after getting pregnant)-ihs(first four quarters before pregnancy)
	*emp_at_dom_fid_yr#=indicator for employed at same firm # years later
	*sepne2yr=seperate to nonemployment within 2 yrs of getting pregnant
	*empft1yrlater=positive earnings in four consecutive qrtrs starting 1 yr after birth
	*de5yr=ihs(total earings five years after birth)-ihs(first four quarters before pregnancy)
	*dfqe=log(earnings first four fq after birth)-log(earnings four fq before pregnancy)
capture program drop gen_outcomevars
program define gen_outcomevars, rclass
	syntax, transdom(string)
egen pre_e = rmean(earn_fq earn_fq_bck1 earn_fq_bck2 earn_fq_bck3)
replace pre_e = log(pre_e)
gen temp=0
gen temp1=.
gen temp2=.
gen temp3=.
gen temp4=.
forvalues i=4/20 {
	replace temp=temp+1 if earn_fq_fwd`i'>0 & earn_fq_fwd`i'!=.
	forvalues q=1/4 {
		replace temp`q'=earn_fq_fwd`i' if temp==`q' & earn_fq_fwd`i'>0 & earn_fq_fwd`i'!=.
	}
}
drop temp
egen post_e = rmean(temp1 temp2 temp3 temp4)
replace post_e = log(post_e)
gen dfqe = post_e - pre_e
sum dfqe, detail
	replace dfqe=`r(p99)' if dfqe>`r(p99)' 
	replace dfqe=`r(p1)' if dfqe<`r(p1)'
drop post_e pre_e
egen pre_e = rmean(earn_total earn_total_bck1 earn_total_bck2 earn_total_bck3)
egen lre = rmean(earn_total_fwd17 earn_total_fwd18 earn_total_fwd19 earn_total_fwd20)
gen de5yr = log(lre+sqrt(lre^2+1))-log(pre_e+sqrt(pre_e^2+1))
drop lre 
egen lre = rmean(earn_total_fwd9 earn_total_fwd10 earn_total_fwd11 earn_total_fwd12)
gen de3yr = log(lre+sqrt(lre^2+1))-log(pre_e+sqrt(pre_e^2+1))
drop pre_e lre
forvalues yr=1/4 {
	forvalues q=1/4 {
		local q`q' = (`yr'-1)*4+`q'
	}
	egen temp=rmean(emp_at_`transdom'_fid_fwd`q1' emp_at_`transdom'_fid_fwd`q2' emp_at_`transdom'_fid_fwd`q3' ///
		emp_at_`transdom'_fid_fwd`q4')
	gen emp_at_samefid_yr`yr'=cond(temp!=. & temp>0,1,0)
	drop temp
}
gen sepne2yr = 0
gen temp=0
forvalues i=1/8 {
	local ip1=`i'+1
	local ip2=`i'+2
	local ip3=`i'+3
	replace sepne2yr=1 if temp==0 & emp_at_`transdom'_fid_fwd`i'!=1 ///
		& emp_at_`transdom'_fid_fwd`ip1'!=1 & emp_at_`transdom'_fid_fwd`ip2'!=1 ///
		& emp_at_`transdom'_fid_fwd`ip3'!=1 & earn_total_fwd`i'==0
	replace temp=1 if emp_at_`transdom'_fid_fwd`i'!=1 ///
		& emp_at_`transdom'_fid_fwd`ip1'!=1 & emp_at_`transdom'_fid_fwd`ip2'!=1 ///
		& emp_at_`transdom'_fid_fwd`ip3'!=1
}
drop temp
gen empft1yrlater = cond( earn_total_fwd9==. ///
	| earn_total_fwd10==. | earn_total_fwd11==. | earn_total_fwd12==. ,.,cond( ///
	earn_total_fwd9>0 & earn_total_fwd10>0 & earn_total_fwd11>0 & earn_total_fwd12>0 ,1,0))	
end
	
*generate covariates
capture program drop gen_covariates
program define gen_covariates, rclass
gen birthyear = 1985+floor( (birth_qtime-1)/4 )
/*foreach x in ethnicity race naics marital_status {
	rename `x' t`x'
	egen `x' = group(t`x')
	drop t`x'
}
*/
destring educ_c, replace
tab educ_c, mi
replace firmsize=1 if firmsize==. | firmsize<0
sum firmsize, detail
replace firmsize = `r(p95)' if firmsize>`r(p95)' & firmsize!=.
gen lnfirmsize = log(firmsize)
egen pre_lnearnings = rmean(earn_total earn_total_bck1 earn_total_bck2 earn_total_bck3)
replace pre_lnearnings = log(pre_lnearnings)
end


*define annual program
capture program drop gen_annual
program define gen_annual, rclass
	syntax, t_back(real) t_forward(real)

local t=0
local t_back_annual_qtr=`t_back'*4
local t_forward_annual_qtr = `t_forward'*4
forvalues i=`t_back_annual_qtr'(-4)4 {
*foreach i in 20 16 12 8 4 {
	local t=`t'+1
	local q0=`i'
	local qm1=`i'-1
	local qm2=`i'-2
	local qm3=`i'-3
	egen earn_total_t`t' = rmean(earn_total_bck`q0' earn_total_bck`qm1' earn_total_bck`qm2' earn_total_bck`qm3')
	replace earn_total_t`t'=earn_total_t`t'*4
}
rename earn_total earn_total_fwd0
forvalues q=0(4)`t_forward_annual_qtr' {
	local t=`t'+1
	local qp1 = `q'+1
	local qp2 = `q'+2
	local qp3 = `q'+3
	egen earn_total_t`t' = rmean(earn_total_fwd`q' earn_total_fwd`qp1' earn_total_fwd`qp2' earn_total_fwd`qp3')
	replace earn_total_t`t'=earn_total_t`t'*4
}

end

capture program drop gen_annual_age
program define gen_annual_age, rclass
replace age = age+(t-2)
end

*define quarterly program
capture program drop gen_quarterly
program define gen_quarterly, rclass
	syntax, t_back(real) t_forward(real)

local t=0
forvalues i=`t_back'(-1)1 {
	local t=`t'+1
	rename earn_total_bck`i' earn_total_t`t'
}
local t=`t'+1
rename earn_total earn_total_t`t'
forvalues i=1/12 {
	local t=`t'+1
	rename earn_total_fwd`i' earn_total_t`t'
}

end

capture program drop gen_quarterly_age
program define gen_quarterly_age, rclass
replace age = age+floor((t-6)/4)
end


}
*end section


*------------------------------------------------------------------------------------------*
*	CLEAN DATA FOR DESCRIPTIVE REGRESSIONS AND COWORKER COMPARISON
*------------------------------------------------------------------------------------------*
{
*load data
use "${interwrk}acs_parent_final.dta", clear
gen parent_flag = 1
append using "${interwrk}coworker_final.dta"
replace parent_flag=0 if parent_flag==.

*generate variables needed for sample restrictions
gen age = 1985+floor( (birth_qtime_bck4-1)/4 )-year(dob)
egen efq_flag = rmean(earn_fq_fwd5 earn_fq_fwd6 earn_fq_fwd7 earn_fq_fwd8 ///
	earn_fq_fwd9 earn_fq_fwd10 earn_fq_fwd11 earn_fq_fwd12)
replace efq_flag = cond(efq_flag!=. & efq_flag>0,1,0)
egen fqback = rmean(earn_fq_bck1 earn_fq_bck2 earn_fq_bck3 earn_fq_bck4)
replace fqback=0 if fqback==.

*implement sample restrictions
keep if tenure_bck>=4 & tenure_bck!=. & top3_f_ratio!=. ///
	& age>=18 & age<=45 & earn_total_bck8!=. & earn_total_fwd12!=. ///
	& earn_total>0 & earn_total_bck1>0 & earn_total_bck2>0 & earn_total_bck3>0 ///
	& fqback<=fq_earn_4qma_p90 & sex=="F"
tab efq_flag, mi
keep if efq_flag==1
tab sex parent_flag, mi col row
drop fqback efq_flag
*retain mothers with matched coworker
replace pik_mother = pik if parent_flag==1
egen coworkerfe = group(pik_mother birth_qtime)
gen nfcw = cond(parent_flag==0 & sex=="F",1,0)
egen nfcw_tot = sum(nfcw), by(coworkerfe)
gen nmother = cond(parent_flag==1 & sex=="F",1,0)
egen nmother_tot = sum(nmother), by(coworkerfe)
tab nfcw_tot nmother_tot, mi
keep if nfcw_tot==1 & nmother_tot==1

*generate important variables
gen educ_lhs = cond(educ_c=="1",1,0)
gen educ_hs = cond(educ_c=="2",1,0)
gen educ_sc = cond(educ_c=="3",1,0)
gen educ_cp = cond(educ_c=="4",1,0)
gen hispanic=cond(ethnicity=="H",1,0)
gen race_white = cond(race=="1",1,0)
gen race_black = cond(race=="2",1,0)
gen race_native = cond(race=="3" | race=="5",1,0)
gen race_asian = cond(race=="4",1,0)
foreach ind in 11 21 22 23 42 51 52 53 54 55 56 61 62 71 72 81 92 {
	gen industry_`ind' = cond(substr(naics,1,2)=="`ind'",1,0)
}
gen industry_31_32_33 = cond(substr(naics,1,2)=="31" | substr(naics,1,2)=="32" ///
	| substr(naics,1,2)=="33",1,0)
gen industry_44_45 = cond(substr(naics,1,2)=="44" | substr(naics,1,2)=="45",1,0)	
gen industry_48_49 = cond(substr(naics,1,2)=="48" | substr(naics,1,2)=="49",1,0)	
replace top3_f_ratio = round(top3_f_ratio*3)
tab top3_f_ratio, mi
replace top1_f_ratio = round(top1_f_ratio)
tab top1_f_ratio, mi

*create key outcome variables
gen_outcomevars, transdom(dom)

*generate control variables
gen_covariates

*generate sample 
gen temp = runiform()
egen uniform = mean(temp), by(coworkerfe)
drop temp

*retain key variables and save data for analysis
keep pik $outcomelist $covarlist  ///
	coworkerfe parent_flag sex ///
	educ_lhs educ_hs educ_sc educ_cp hispanic ///
	race_white race_black race_native race_asian industry_* ///
	birth_qtime_bck4 dom_sein_bck4 num_estabs ///
	earn_total* top1_is_parent last_birth_qtime uniform
compress
save "${datatemp}temp.dta", replace
drop earn_total_*
sum
save "${datatemp}cleandata_reg.dta", replace
}
*end section


*------------------------------------------------------------------------------------------*
*	CLEAN PANEL DATA FOR COWORKER COMPARISON
*------------------------------------------------------------------------------------------*
{
foreach freq in annual quarterly {
use "${datatemp}temp.dta", clear

*generate earnings for panel
gen_`freq', t_back(`t_back_`freq'') t_forward(`t_forward_`freq'')
sum earn_total_t*
gen educ = cond(educ_lhs==1,1,cond(educ_hs==1,2,cond(educ_sc==1,3,cond(educ_cp==1,4,0))))
tab educ, mi
*reshape to long
preserve
keep pik coworkerfe top3_f_ratio birth_qtime_bck4 ///
	dom_sein_bck4 parent_flag earn_total_t* age educ ///
	birth_order last_birth_qtime race ethnicity firmsize ///
	num_estabs top1_is_parent naics top1_f_ratio uniform
save "${datatemp}evenstudypanel_`freq'.dta", replace
restore
keep pik birth_qtime_bck4 earn_total_t*
reshape long earn_total_t, ///
	i(pik birth_qtime_bck4) j(t)
merge m:1 pik birth_qtime_bck4 using "${datatemp}evenstudypanel_`freq'.dta"
drop _merge

*generate panel variables for fixed effect estimator
egen pik_fe = group(pik birth_qtime_bck4)
rename earn_total_t earn_total
gen_`freq'_age
gen age2 = age^2
sum t, detail
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/3 {
	gen byte d_f`f'_t`t' = cond(parent_flag==1,cond(t==`t' & top3_f_ratio==`f',1,0),0)
}
}
*winsorize at the 95th percentile
sum earn_total, detail
replace earn_total=`r(p95)' if earn_total>`r(p95)' & earn_total!=.

*save output data
compress
save "${datatemp}evenstudypanel_`freq'.dta", replace
}
rm  "${datatemp}temp.dta"
}
*end section 


*------------------------------------------------------------------------------------------*
*	CLEAN DATA FOR MANAGER TRANSITION
*------------------------------------------------------------------------------------------*
{

*LOAD DATA
use "${interwrk}mngr_tr_final.dta", clear
tab sex, mi
keep if sex=="F"
gen parent_flag=1
append using "${interwrk}coworker_final.dta"
replace parent_flag=0 if parent_flag==.

*generate variables for sample restriction
gen age = 1985+floor( (birth_qtime-1)/4 )-year(dob)
sum age, detail
tab sex, mi
egen efq_flag = rmean(earn_fq_fwd5 earn_fq_fwd6 earn_fq_fwd7 earn_fq_fwd8 ///
	earn_fq_fwd9 earn_fq_fwd10 earn_fq_fwd11 earn_fq_fwd12)
replace efq_flag = cond(efq_flag!=. & efq_flag>0,1,0)

*implement sample restrictions
keep if tenure_bck>=4 & tenure_bck!=. & earn_total_bck8!=. & earn_total_fwd12!=. ///
	& earn_total>0 & earn_total_bck1>0 & earn_total_bck2>0 & earn_total_bck3>0 ///
	& age>=18 & age<=45
tab efq_flag, mi
keep if efq_flag==1

*create key outcome variables
gen_outcomevars, transdom(trans)

*generate covariates
gen_covariates

*generate other important variables
egen mngr_transition_fe = group(transition_sein transition_qtime)
gen birth_pre_trans = cond(birth_qtime<transition_qtime,1,0)
tab transition_sex birth_pre_trans, mi
gen mngr_female = cond(substr(transition_sex,1,1)=="F" & birth_pre_trans==1,1, ///
	cond(substr(transition_sex,2,1)=="F" & birth_pre_trans==0,1,0))
tab transition_sex mngr_female, mi
replace pik_mother = pik if parent_flag==1
egen coworkerfe = group(pik_mother birth_qtime)

*retain key variables
keep pik $outcomelist $covarlist mngr_transition_fe mngr_female ///
	new_mngr_tenure_bck transition_sex birth_pre_trans transition_qtime coworkerfe

*create separate datasets for mothers and fathers
foreach sex in M F {
preserve
keep if sex=="`sex'"
drop sex
*retain observations with at least one obs in pre and one in post transition period
save "${datatemp}mngr_transition_`sex'.dta", replace
keep mngr_transition_fe birth_pre_trans
gen obs=1
gen birth_post_trans=1-birth_pre_trans
collapse (sum) obs (max) birth_pre_trans birth_post_trans, by(mngr_transition_fe)
tab birth_pre_trans birth_post_trans, mi
keep if birth_pre_trans==1 & birth_post_trans==1
sum obs, detail
keep mngr_transition_fe
merge 1:m mngr_transition_fe using "${datatemp}mngr_transition_`sex'.dta"
keep if _merge==3
drop _merge
*save output data
compress
save "${datatemp}mngr_transition_`sex'.dta", replace
restore
}
}
*end section

*------------------------------------------------------------------------------------------*
*	CLEAN PANEL DATA FOR MANAGER TRANSITION
*------------------------------------------------------------------------------------------*
{

local freq quarterly

*LOAD DATA
use "${interwrk}mngr_tr_final.dta", clear
keep if sex=="F"
rename pik pik_mother
rename transition_sein dom_sein_bck4
keep pik_mother birth_qtime sex dom_sein_bck4 transition_qtime transition_sex
merge m:1 pik_mother birth_qtime sex dom_sein_bck4 using "${interwrk}coworker_final.dta"
keep if _merge==3
drop _merge
rename dom_sein_bck4 transition_sein
gen parent_flag=0
append using  "${interwrk}mngr_tr_final.dta"
replace parent_flag=1 if parent_flag==.
gen age = 1985+floor( (birth_qtime-1)/4 )-year(dob)
sum age, detail
tab sex, mi
egen efq_flag = rmean(earn_fq_fwd5 earn_fq_fwd6 earn_fq_fwd7 earn_fq_fwd8 ///
	earn_fq_fwd9 earn_fq_fwd10 earn_fq_fwd11 earn_fq_fwd12)
replace efq_flag = cond(efq_flag!=. & efq_flag>0,1,0)
egen fqback = rmean(earn_fq_bck1 earn_fq_bck2 earn_fq_bck3 earn_fq_bck4)
replace fqback=0 if fqback==.

*implement sample restrictions
keep if tenure_bck>=4 & tenure_bck!=. & earn_total_bck8!=. & earn_total_fwd12!=. ///
	& age>=18 & age<=45 & fqback<=fq_earn_4qma_p90 ///
	& earn_total>0 & earn_total_bck1>0 & earn_total_bck2>0 & earn_total_bck3>0 ///
	& sex=="F"
tab efq_flag, mi
keep if efq_flag==1
*retain mothers with matched coworker
replace pik_mother = pik if parent_flag==1
egen coworkerfe = group(pik_mother birth_qtime transition_sein)
gen nfcw = cond(parent_flag==0 & sex=="F",1,0)
egen nfcw_tot = sum(nfcw), by(coworkerfe)
gen nmother = cond(parent_flag==1 & sex=="F",1,0)
egen nmother_tot = sum(nmother), by(coworkerfe)
tab nfcw_tot nmother_tot, mi
keep if nfcw_tot==1 & nmother_tot==1

*generate earnings for panel
gen_`freq', t_back(`t_back_`freq'') t_forward(`t_forward_`freq'')
sum earn_total_t*

*generate important variables
egen mngr_transition_fe = group(transition_sein transition_qtime)
egen pik_fe = group(pik mngr_transition_fe birth_qtime)
gen birth_pre_trans = cond(birth_qtime<transition_qtime,1,0)
tab transition_sex birth_pre_trans, mi
gen mngr_female = cond(substr(transition_sex,1,1)=="F" & birth_pre_trans==1,1, ///
	cond(substr(transition_sex,2,1)=="F" & birth_pre_trans==0,1,0))
tab transition_sex mngr_female, mi
destring educ_c, replace
rename educ_c educ
tab educ, mi

*retain observations with at least one obs in pre and one in post transition period
*and sex of leadership changes
save "${datatemp}mngr_transition_panel.dta", replace
keep if parent_flag==1
keep mngr_transition_fe mngr_female
gen mngr_male=1-mngr_female
collapse (max) mngr_female mngr_male, by(mngr_transition_fe)
tab mngr_female mngr_male, mi
keep if mngr_female==1 & mngr_male==1
keep mngr_transition_fe
merge 1:m mngr_transition_fe using "${datatemp}mngr_transition_panel.dta"
keep if _merge==3
drop _merge
duplicates report pik_fe
duplicates drop pik_fe, force

*reshape to long
preserve
keep pik_fe birth_qtime age educ ///
	transition_sex birth_pre_trans mngr_transition_fe mngr_female ///
	new_mngr_tenure_bck transition_qtime coworkerfe parent_flag transition_sein
gen temp = runiform()
egen uniform = mean(temp), by(mngr_transition_fe)
drop temp
save "${datatemp}mngr_transition_panel.dta", replace
restore
keep pik_fe earn_total_t*
reshape long earn_total_t, ///
	i(pik_fe) j(t)
merge m:1 pik_fe using "${datatemp}mngr_transition_panel.dta"
drop _merge

*generate panel variables for fixed effect estimator
rename earn_total_t earn_total
gen_`freq'_age
gen age2 = age^2
sum t, detail
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/1 {
	gen byte d_f`f'_t`t' = cond(parent_flag==1,cond(t==`t' & mngr_female==`f',1,0),0)
}
}
*winsorize at the 95th percentile
sum earn_total, detail
replace earn_total=`r(p95)' if earn_total>`r(p95)' & earn_total!=.

*save output data
compress
save "${datatemp}mngr_transition_panel.dta", replace
}
*end section
