*------------------------------------------------------------------------------------------*
* FIGURE 11
*------------------------------------------------------------------------------------------*

*define outcome variables
global covars c.age#i.educ c.age2#i.educ

*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*define sample size
local freq quarterly
local samplesize r(p25)

*define number of significant digits
global sigdignum=3

*estimate for total earnings
local y earn_total

*load data
use "${datatemp}evenstudypanel_`freq'.dta", clear
tab t, mi
gen naics2 = substr(naics,1,2)
gen earn_positive = cond(earn_total>0,1,0)

*create binary treatment indicator
gen female_exec = cond(top3_f_ratio==.,.,cond(top3_f_ratio>0,1,0))
tab top3_f_ratio female_exec, mi 
drop d_f*
sum t, detail
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/1 {
	gen byte d_f`f'_t`t' = cond(parent_flag==1,cond(t==`t' & female==`f',1,0),0)
}
}
sum firmsize, detail
gen large_firm = cond(firmsize==.,.,cond(firmsize<500,0,1))
tab large_firm, mi

*check treatment within subsamples
tab naics2 female_exec, mi

*estimate for each industry
local indlist 11 21 22 23 32 31 33 42 44 45 48 49 51 52 53 54 55 56 61 62 71 72 81 92
foreach ind in `indlist' {
foreach large_firm in 0 1 {
gen temp_flag = cond(parent_flag==1 & naics2=="`ind'" & large_firm==`large_firm',1,0)
egen sample_flag = max(temp_flag), by(coworkerfe)
tab female_exec if sample_flag==1, mi

reghdfe `y' d_f* $covars if sample_flag==1, absorb(pik_fe i.coworkerfe##i.t) vce(cluster coworkerfe)
local f=0
lincom (_b[d_f`f'_t18]+_b[d_f`f'_t19]+_b[d_f`f'_t20]+_b[d_f`f'_t21])/4 
scalar b_ind`ind'_lrgfrm`large_firm'_f`f' = `r(estimate)'
scalar se_ind`ind'_lrgfrm`large_firm'_f`f' = `r(se)'
forvalues f=1/1 {
		lincom (_b[d_f`f'_t18]+_b[d_f`f'_t19]+_b[d_f`f'_t20]+_b[d_f`f'_t21])/4 ///
			- (_b[d_f0_t18]+_b[d_f0_t19]+_b[d_f0_t20]+_b[d_f0_t21])/4
		scalar b_ind`ind'_lrgfrm`large_firm'_f`f' = `r(estimate)'
		scalar se_ind`ind'_lrgfrm`large_firm'_f`f' = `r(se)'
}
drop temp_flag sample_flag
}
}

keep if parent_flag==1 & t-`t_back_`freq''-1-`t_unit_`freq''==0
keep naics2 large_firm female_exec
gen unique_mothers=1
collapse (sum) unique_mothers, by(naics2 large_firm female_exec)
gen double b=.
gen double se=.
foreach ind in `indlist' {
foreach large_firm in 0 1 {
forvalues f=0/1 {
foreach type in b se {
	replace `type' = scalar(`type'_ind`ind'_lrgfrm`large_firm'_f`f') ///
		if naics2=="`ind'" & large_firm==`large_firm' & female_exec==`f'
}
}
}
}
*save output
order naics2 large_firm female_exec
sort naics2 large_firm female_exec

rename unique mothers_n_
reshape wide b se mothers_n_, i(naics2 large_firm) j(female_exec)
tostring naics2, replace
tempfile temp
save `temp'
import sas "${output}occtype_freq_top1_indsz_rr", clear
gen is_mngr_percent = is_mngr/n
rename is_mngr is_mngr_1
gen is_mngr_0 = n-is_mngr_1
rename industry_2d naics2
keep naics2 large_firm is_mngr_percent is_mngr_*
merge 1:m naics2 large_firm using `temp'
keep if _merge==3 
drop _merge 
keep naics2 large_firm is_mngr_percent is_mngr_1 is_mngr_0 b0 se0 b1 se1 mothers_n_0 mothers_n_1
order naics2 large_firm is_mngr_percent is_mngr_1 is_mngr_0 b0 se0 b1 se1 mothers_n_0 mothers_n_1

*output file
gen mothers_n=mothers_n_0+mothers_n_1
keep naics2 large_firm is_mngr_percent b0 se0 b1 se1 mothers_n
foreach x in is_mngr_percent b0 se0 b1 se1 {
	sigdigitsvar, val_sd(`x') sigdigit_sd($sigdignum)
}
drbroundvar, x(mothers_n)
destring mothers_n_rounded, replace
drop mothers_n
rename mothers_n_rounded mothers_n

reg b1 is_mngr_percent [aw=mothers_n]
*drop outlier
drop if naics2=="49" & large_firm==0
reg b1 is_mngr_percent [aw=mothers_n]
graph twoway (scatter b1 is_mngr_percent [aw=mothers_n], color(dknavy%30) graphregion(color(white))) ///
	(lfit b1 is_mngr_percent [aw=mothers_n], color(dknavy) graphregion(color(white))) ///
	, legend(off) ///
	xtitle("Percent of top earners that are managers", size(medium)) ///
	ytitle("Penalty relative to no female top earners", size(medium))
graph export "${tables_figures}figure_11.pdf", as(pdf) replace	
	

di "END OF PROGRAM: NO ERRORS"
