*------------------------------------------------------------------------------------------*
* FIGURE 12
*------------------------------------------------------------------------------------------*

*define outcome variables
global covars c.age#i.educ c.age2#i.educ

*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*define sample size
local freq quarterly
local samplesize r(p25)

*define number of significant digits
global sigdignum=3

*------------------------------------------------------------------------------------------*
*	COMPARISON TO COWORKERS: ALTERNATIVE LEADERSHIP MEASURE
*------------------------------------------------------------------------------------------*
{

*define outcome variable 
local y earn_total

*load data
use "${datatemp}evenstudypanel_`freq'.dta", clear

drop d_f*

*for quarterly data use subsample to reduce computational burden
if "`freq'"=="quarterly" {
	sum uniform, detail
	keep if uniform<``samplesize''
}

tab top1_f_ratio, mi
sum t, detail
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/1 {
	gen byte d_f`f'_t`t' = cond(parent_flag==1,cond(t==`t' & top1_f_ratio==`f',1,0),0)
}
}

local m=1
reghdfe `y' d_f* $covars, absorb(pik_fe i.coworkerfe##i.t) vce(cluster coworkerfe)
foreach var of varlist d_f* {
	scalar m`m'_b_`var'  = _b[`var']
	scalar m`m'_se_`var'  = _se[`var']
}

*save output
keep t top1_f_ratio
duplicates drop
forvalues m=1/1 {
	gen double m`m'_b = .
	gen double m`m'_se = .
}
sum t, detail
forvalues m=1/1 {
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/1 {
	replace m`m'_b = scalar(m`m'_b_d_f`f'_t`t') if t==`t' & top1_f_ratio==`f'
	replace m`m'_se = scalar(m`m'_se_d_f`f'_t`t') if t==`t' & top1_f_ratio==`f'
}
}
}
replace t = t-`t_back_`freq''-1-`t_unit_`freq''
keep if t>=-6
forvalues m=1/1 {
sigdigitsvar, val_sd(m`m'_b) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m`m'_se) sigdigit_sd($sigdignum)
}

*figure 12a
drop if t<-6
sort t
forvalues m=1/1 {
gen upper = m`m'_b+1.96*m`m'_se
gen lower = m`m'_b-1.96*m`m'_se
local selist
forvalues f=0/1 {
	local selist `selist' (connected upper t if top1_f_ratio==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
	local selist `selist' (connected lower t if top1_f_ratio==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
}
graph twoway `selist' ///
	(connected m`m'_b t if top1_f_ratio==0, color(gs0) msymbol(circle) graphregion(color(white))) ///
	(connected m`m'_b t if top1_f_ratio==1, color(gs9) msymbol(diamond) graphregion(color(white))), ///
	legend(label(5 "Male") label(6 "Female") order(5 6) ///
	title("Sex of top earner", color(black) size(medium)) region(lcolor(white))) ///
	xtitle("Quarters after birth of child") ytitle("Quarterly earnings") ///
	xscale(range(-6 8)) xlabel(-6[2]8)
graph export "${tables_figures}Figure_12a.pdf", replace as(pdf)
drop upper lower
}

}
*end section 

*------------------------------------------------------------------------------------------*
*	COMPARISON TO COWORKERS: LEADER IS PARENT
*------------------------------------------------------------------------------------------*
{

*define outcome variable 
local y earn_total

*load data
use "${datatemp}evenstudypanel_`freq'.dta", clear

drop d_f*

tab top1_f_ratio top1_is_parent, mi
gen temp_flag = cond(parent_flag==1 & (top1_is_parent=="P" | top1_is_parent=="N"),1,0)
egen sample_flag = max(temp_flag), by(coworkerfe)
keep if sample_flag==1
replace top1_f_ratio=0 if parent_flag==0

gen top1_parent = cond(top1_f_ratio!=1,0,cond(top1_is_parent=="P",2,1))
	
tab top1_f_ratio, mi
sum t, detail
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/2 {
	gen byte d_f`f'_t`t' = cond(parent_flag==1,cond(t==`t' & top1_parent==`f',1,0),0)
}
}

local m=1
reghdfe `y' d_f* $covars, absorb(pik_fe i.coworkerfe##i.t) vce(cluster coworkerfe)
foreach var of varlist d_f* {
	scalar m`m'_b_`var'  = _b[`var']
	scalar m`m'_se_`var'  = _se[`var']
}

*save output
keep t top1_parent
duplicates drop
forvalues m=1/1 {
	gen double m`m'_b = .
	gen double m`m'_se = .
}
sum t, detail
forvalues m=1/1 {
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/2 {
	replace m`m'_b = scalar(m`m'_b_d_f`f'_t`t') if t==`t' & top1_parent==`f'
	replace m`m'_se = scalar(m`m'_se_d_f`f'_t`t') if t==`t' & top1_parent==`f'
}
}
}
replace t = t-`t_back_`freq''-1-`t_unit_`freq''
keep if t>=-6
forvalues m=1/1 {
sigdigitsvar, val_sd(m`m'_b) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m`m'_se) sigdigit_sd($sigdignum)
}


*figure 12b
drop if t<-6
sort t
forvalues m=1/1 {
gen upper = m`m'_b+1.96*m`m'_se
gen lower = m`m'_b-1.96*m`m'_se
local selist
forvalues f=0/2 {
	local selist `selist' (connected upper t if top1_parent==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
	local selist `selist' (connected lower t if top1_parent==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
}
graph twoway `selist' ///
	(connected m`m'_b t if top1_parent==0, color(gs0) msymbol(circle) graphregion(color(white))) ///
	(connected m`m'_b t if top1_parent==1, color(gs5) msymbol(triangle) graphregion(color(white))) ///
	(connected m`m'_b t if top1_parent==2, color(gs9) msymbol(diamond) graphregion(color(white))), ///
	legend(label(7 "Male") label(8 "Female, not mother") label(9 "Female, mother") order(7 8 9) ///
	title("Description of top earner", color(black) size(medium)) region(lcolor(white)) col(1)) ///
	xtitle("Quarters after birth of child") ytitle("Quarterly earnings") ///
	xscale(range(-6 8)) xlabel(-6[2]8)
graph export "${tables_figures}figure_12b.pdf", replace as(pdf)
drop upper lower
}
}
*end section 
