*------------------------------------------------------------------------------------------*
*	FIGURE 13
*------------------------------------------------------------------------------------------*
{
*define outcome variables
global covars c.age#i.educ c.age2#i.educ

*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*define sample size
local freq quarterly
local samplesize r(p25)

*define number of significant digits
global sigdignum=3

*load data
use "${datatemp}mngr_transition_panel.dta", clear

*for quarterly data use subsample to reduce computational burden
if "`freq'"=="quarterly" {
	sum uniform, detail
	*keep if uniform<``samplesize''
}

gen timingdiff = abs(transition_qtime-birth_qtime)
sum timingdiff, detail
tab timingdiff, mi
tab t, mi
tab mngr_female, mi
tab birth_pre_trans mngr_female, mi
tab parent_flag, mi

sum earn_total, detail

*model 2
reghdfe earn_total d_f1* $covars, vce(cluster mngr_transition_fe) ///
	absorb(pik_fe i.mngr_transition_fe##i.t##i.parent_flag  i.coworkerfe##i.t)
keep if e(sample)==1
foreach var of varlist d_f1* {
	scalar m2_b_`var'  = _b[`var']
	scalar m2_se_`var'  = _se[`var']
}

*model 1
reghdfe earn_total d_f1* $covars if parent_flag==1, vce(cluster mngr_transition_fe) ///
	absorb(pik_fe i.mngr_transition_fe##i.t)
foreach var of varlist d_f1* {
	scalar m1_b_`var'  = _b[`var']
	scalar m1_se_`var'  = _se[`var']
}

/*model 3
reghdfe earn_total d_f1* $covars if timingdiff<=8, vce(cluster mngr_transition_fe) ///
	absorb(pik_fe i.mngr_transition_fe##i.t##i.parent_flag  i.coworkerfe##i.t)
foreach var of varlist d_f1* {
	scalar m3_b_`var'  = _b[`var']
	scalar m3_se_`var'  = _se[`var']
}

*model 4
reghdfe earn_total d_f1* $covars if timingdiff>4, vce(cluster mngr_transition_fe) ///
	absorb(pik_fe i.mngr_transition_fe##i.t##i.parent_flag  i.coworkerfe##i.t)
foreach var of varlist d_f1* {
	scalar m4_b_`var'  = _b[`var']
	scalar m4_se_`var'  = _se[`var']
}
*/

keep t parent_flag mngr_female earn_total
*disclosure statistics
preserve
keep if t==6
keep parent_flag mngr_female
gen observations=1
collapse (sum) observations, by(parent_flag mngr_female)
export delimited using "${support_dir}mngrtransition_samplesize.csv", replace
drbroundvar, x(observations)
drop observations
export delimited using "${output_dir}mngrtransition_samplesize.csv", replace
restore
*save output
keep if parent_flag==1 & mngr_female==0
keep t earn_total
collapse (mean) earn_total, by(t) fast
forvalues m=1/2 {
forvalues f=1/1 {
	gen double m`m'_b_f`f' = .
	gen double m`m'_se_f`f' = .
}
}
sum t, detail
forvalues m=1/2 {
forvalues f=1/1 {
forvalues t=`t_pre_`freq''/`r(max)' {
	replace m`m'_b_f`f' = scalar(m`m'_b_d_f`f'_t`t') if t==`t'
	replace m`m'_se_f`f' = scalar(m`m'_se_d_f`f'_t`t') if t==`t'
}
}
}
replace t = t-`t_back_`freq''-1-`t_unit_`freq''
keep if t>=-6
sigdigitsvar, val_sd(m1_b_f1) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m1_se_f1) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m2_b_f1) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m2_se_f1) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(earn_total) sigdigit_sd($sigdignum)


drop if t<-6
sort t
forvalues m=1/2 {
forvalues f=1/1 {
replace m`m'_b_f`f' = earn_total+m`m'_b_f`f'
gen upper_m`m'_f`f' = m`m'_b_f`f'+1.96*m`m'_se_f`f'
gen lower_m`m'_f`f' = m`m'_b_f`f'-1.96*m`m'_se_f`f'
}
}
local selist
forvalues m=1/2 {
forvalues f=1/1 {
	local selist `selist' (connected upper_m`m'_f`f' t, lpattern(dash) msymbol(none) ///
		lcolor(gs12) graphregion(color(white)))
	local selist `selist' (connected lower_m`m'_f`f' t, lpattern(dash) msymbol(none) ///
		lcolor(gs12) graphregion(color(white)))
}
}
graph twoway `selist' ///
	(line earn_total t, color(gs0) lwidth(thick) graphregion(color(white))) ///
	(connected m1_b_f1 t, color(gs9) lpattern(longdash) msymbol(circle) graphregion(color(white))) ///
	(connected m2_b_f1 t, color(gs6) lpattern(longdash)  msymbol(triangle) graphregion(color(white))), ///
	legend(label(5 "Average outcomes for new mothers, top earner male") ///
		label(6 "Predicted outcomes, top earner female (mother comparison)")  ///
		label(7 "Predicted outcomes, top earner female (coworker comparison)") ///
		order(5 6 7) col(1) region(lcolor(white)) size(small)) ///
	xtitle("Quarters after birth of child") ytitle("Quarterly earnings") ///
	xscale(range(-6 8)) xlabel(-6[2]8)
graph export "${tables_figures}figure_13.pdf", replace as(pdf)

}
*end section
