/*********************************************************************************************

	WRITTEN BY: MATTHEW STAIGER
		Identifies PIKs that appear in any ACS survey from 2001 through 2017. 
	
	OUTPUT DATASET: interwrk.acs_pik_list
		VARIABLES: pik $9 acs_year $4;
*********************************************************************************************/

*%include "../config.sas";


%macro gen_acs_pik_list;

%DO yr=2001 %TO 2017;

data acs_xwalk_&yr.(keep=pik acs_year) /view=acs_xwalk_&yr.;
    set acsx&yr..crosswalk_acs&yr.;
    
    acs_year = "&yr.";
run;
    
%END;
    
data tmp_acs_list;
   set  %do yr = 2001 %to 2017;
        acs_xwalk_&yr.
    %end;
    ;
run;  

proc sort data=tmp_acs_list;
    by pik acs_year;
run;
    
* remove duplicates;
data tmp_dup_piks;
    set tmp_acs_list;
    by pik acs_year;
    
    if first.acs_year then do;
        is_unique = 1;
    end;
    else is_unique = 0;
        
    if last.acs_year then output;
run;
        
data interwrk.acs_pik_list;
    merge tmp_acs_list
          tmp_dup_piks;
    by pik acs_year;
        
    if is_unique = 1 then output;
run;

%mend;
        
%gen_acs_pik_list;
