/*********************************************************************************************

	WRITTEN BY: SETH MURRAY
		 Identifies whether the top earner at the SEIN is a mother at the time of
		 being the top earner (for those women for which we have enough survey data to
		 determine whether they were a mother given their age and the survey coverage).

	OUTPUT DATASETS:
		- interwrk.top_1F_is_parent
		- interwrk.top_1M_is_parent
		- interwrk.sein_top_earner_pik_plus
		- interwrk.sein_top_earner_fwd_pik_plus 
*********************************************************************************************/


proc sort data=interwrk.sein_top_earner_pik
          out=tmp_top_e
          nodupkey;
    by pik ;
run;
    
proc sort data=interwrk.pikscenacs;
    by pik;
run;
    
data interwrk.top_1F_is_parent(keep=pik b_qtime1-b_qtime10 top1_is_parent nuntil age_fsy age_lsy top1_yob first_survey_yr last_survey_yr)
     interwrk.top_1M_is_parent(keep=pik b_qtime1-b_qtime10 top1_is_parent pik_partner top1_yob);
    length top1_is_parent $1 nuntil 4 pik_partner $9 dob  4 birth_qtime 3;
    merge tmp_top_e (in=in_top_earner)
          interwrk.pikscenacs (in=in_census
                               rename=(acs2001=acs1
                                       acs2002=acs2
                                       acs2003=acs3
                                       acs2004=acs4
                                       acs2005=acs5
                                       acs2006=acs6
                                       acs2007=acs7
                                       acs2008=acs8
                                       acs2009=acs9
                                       acs2010=acs10
                                       acs2011=acs11
                                       acs2012=acs12
                                       acs2013=acs13
                                       acs2014=acs14
                                       acs2015=acs15
                                       acs2016=acs16
                                       acs2017=acs17
                                      )
                );
    by pik;
            
    array b_qtime {10};
    array a_acs {18} acs1-acs18;
        
    if _n_ = 1 then do;
        declare hash p_h (dataset:"interwrk.parentchild",hashexp:16,multidata:"Y");
        p_h.defineKey("pik");
        p_h.defineData("birth_qtime","pik_partner");
        p_h.defineDone();
            
        declare hash pik_dob (dataset:"lehd_t13.icf_us", hashexp:16);
            pik_dob.defineKey('pik');
            pik_dob.defineData('dob');
            pik_dob.defineDone();
    
    end;
    
    *  Keep only if a top earner;        
    if in_top_earner = 1 then do;
        * check if parent;
        rc = p_h.find();
        if rc = 0 then do;
            top1_is_parent="P";
            p_cntr =  0;
        end;    
        do while(rc=0);
            p_cntr = p_cntr + 1;
            * identify set of birth  qtimes;
            if p_cntr <= 10 then do;
                b_qtime{p_cntr}  = birth_qtime;
            end;
        
            rc = p_h.find_next();
        end;


        rc_dob = pik_dob.find();
        if rc_dob = 0  then do;
            yob = year(dob);
        end;
        
  
            * identify the first and last year in which the  individual was surveyed;
            if cen2000 = 1 then first_survey_yr = 2000;
            else if cen2010 = 1 then first_survey_yr=2010;  
                                    
            if cen2010 = 1 then last_survey_yr = 2010;
            else if cen2000 = 1 then last_survey_yr=2000;  
                                    
            do i=1 to 17;
               if a_acs{i} = 1 then do;
                    
                    if first_survey_yr = . then first_survey_yr = i +  2000;
                    else if i < first_survey_yr - 2000 then first_survey_yr = i + 2000;
                    
                    if last_survey_yr  = .  then last_survey_yr = i + 2000;
                    else if  i > last_survey_yr - 2000 then last_survey_yr = i + 2000;
               end;                     
                                    
            end;                                              
              
            * get the individuals DOB;  
            rc_dob = pik_dob.find();
            if rc_dob = 0 and first_survey_yr ~= . then do;
                age_fsy = floor(YRDIF(dob, mdy(6,1,first_survey_yr),'AGE'));
                age_lsy = floor(YRDIF(dob, mdy(6,1,last_survey_yr) ,'AGE'));
                    
                * if observe person for all ages 18-40 and no children;
                if age_fsy ~= . and age_fsy <= 36 and age_lsy >= 40 then do;
                    if top1_is_parent = "" then top1_is_parent = "N";
                    NUntil = &last_year. + 10;
                end;
                else if age_lsy ~= . and  age_lsy <=36  then do;
                    if top1_is_parent = "" then top1_is_parent =  "N";
                    NUntil = last_survey_yr;
                end;
            end;

            top1_yob = yob;
        
    
        if sex = "F" then output interwrk.top_1F_is_parent;
        if sex = "M" then output interwrk.top_1M_is_parent;
    end;
run;
                    
proc freq data=interwrk.top_1F_is_parent;
    table top1_is_parent /missing;
    table nUntil /missing;      
    table top1_yob /missing;
    table top1_yob*top1_is_parent /missing;
run;    
    *proc print data=interwrk.top_1F_is_parent(obs=200);
                    
proc freq data=interwrk.top_1M_is_parent;
    table top1_is_parent /missing;    
    table top1_yob /missing;
    table top1_yob*top1_is_parent /missing;
run;    
    

proc sort data=interwrk.sein_top_earner_pik;
    by pik ;
run;
            
data interwrk.sein_top_earner_pik_plus;
    merge interwrk.sein_top_earner_pik (in=in_top_earner)
          interwrk.top_1F_is_parent(keep=pik top1_is_parent top1_yob nUntil);
    by pik;
        
    if in_top_earner then output;
run;

proc sort data=interwrk.sein_top_earner_fwd_pik;
    by pik ;
run;
            
data interwrk.sein_top_earner_fwd_pik_plus;
    merge interwrk.sein_top_earner_fwd_pik(in=in_top_earner)
          interwrk.top_1F_is_parent(keep=pik top1_is_parent top1_yob nUntil);
    by pik;
        
    if in_top_earner then output;
run;

proc contents data=interwrk.top_1F_is_parent;
proc contents data=interwrk.sein_top_earner_pik_plus;
        
