/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Converts nominal to real earnings for the various earnings files using the CPI.  Generates the STATA dateset used for the manager transitions regression analyses.

	OUTPUT DATASETS:
	       - interwrk.acs_parent_final
	       - interwrk.mngr_tr_final
	       - interwrk.coworker_final
*********************************************************************************************/


*%include "../config.sas";

* 2015 real dollars;   
proc import datafile="cpi.csv"
            out=temp_cpi
            dbms=CSV;
run;

proc contents data=temp_cpi;
            
data inputs.cpi;
    set temp_cpi;
    
    qtime = (year-1985)*4 + quarter;
    
    cpi_adjustment = 100 / cpi_index;
run;
    
proc contents data=inputs.cpi;
proc print data=inputs.cpi;
            

%macro  nom_to_real(file_nm);
    
  
proc contents data=interwrk.&file_nm._earn_plus_demo_bck4;
proc print data=interwrk.&file_nm._earn_plus_demo_bck4 (obs=20);
    
data interwrk.&file_nm._final(drop=qtime cpi_adjustment rc);
    set interwrk.&file_nm._earn_plus_demo_bck4;
    
    if _n_ = 1 then do;
        declare hash cpi_data (dataset:"inputs.cpi");
            cpi_data.defineKey("qtime");
            cpi_data.defineData("cpi_adjustment");
            cpi_data.defineDone();
    
    end;
            
    %do i  = 1 %to 20;
        cpi_adjustment = .;
        qtime = birth_qtime - &i.;
        rc = cpi_data.find();
        if rc = 0 then do;
            earn_fq_bck&i = earn_fq_bck&i * cpi_adjustment;
            earn_total_bck&i = earn_total_bck&i * cpi_adjustment;
        end;
    %end;
    qtime = birth_qtime;
    if qtime <= &last_qtime. then do;
	rc = cpi_data.find();
    if rc = 0 then do;
		earn_fq = earn_fq * cpi_adjustment; 
		earn_total = earn_total * cpi_adjustment;
	end;
	end;
    %do i = 1  %to 20;
        cpi_adjustment = .;
        qtime = birth_qtime + &i.;
        if qtime <= &last_qtime. then do;
            
            rc = cpi_data.find();
            if rc = 0 then do;
                earn_fq_fwd&i = earn_fq_fwd&i * cpi_adjustment; 
                earn_total_fwd&i = earn_total_fwd&i * cpi_adjustment;
            end;
        end;
    %end;
            
run;


proc print data=interwrk.&file_nm._final (obs=20);


%if "&ind_type." = "mngr_tr" %then %do;
    * export the data sets to Stata;

    proc export data=interwrk.&file_nm._final
            file="/interwrk/&file_nm._final"
            dbms=stata replace;
    run;
%end;
   
%mend;
    

*%nom_to_real(parent);
%nom_to_real(acs_parent);
%nom_to_real(coworker);
%nom_to_real(mngr_tr);
