/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Adds an indicator if the top earner at the firm is a parent.  Generates the 2
		 STATA datesets used for the coworker regression analyses.

	OUTPUT DATASETS:
	       - interwrk.acs_parent_final_rr
	       - interwrk.coworker_final_rr
	       - /interwrk/acs_parent_final_rr.dta 
	       - /interwrk/coworker_final_rr.dta 
*********************************************************************************************/

    
    
data tmp_top;
    set interwrk.sein_top_earner_pik_plus;
    where top1_is_parent ~= "";
run;
    
    
proc sort data=tmp_top NODUPKEY;
    by sein qtime;
run;

    
data tmp_top_dob;
    set interwrk.sein_top_earner_pik (rename=(dob=top1_dob));
run;
    
    
proc sort data=tmp_top_dob NODUPKEY;
    by sein qtime;
run;
    
%macro process_top_is_parent(file_nm);    

proc sort data=interwrk.&file_nm._final_rr;
    by dom_sein_bck4 birth_qtime_bck4;
run;

data tmp_merge;
    merge interwrk.&file_nm._final_rr (in=in_target)
          tmp_top_dob (keep= sein qtime top1_dob
                         rename=(sein=dom_sein_bck4 qtime=birth_qtime_bck4));
    by dom_sein_bck4 birth_qtime_bck4;
                        
    if in_target then output;
run;

data interwrk.&file_nm._final_rr(drop=year  nuntil);
    merge tmp_merge (in=in_target)
          tmp_top (keep=sein qtime top1_is_parent nuntil 
			rename=(sein=dom_sein_bck4 qtime=birth_qtime_bck4));
    by dom_sein_bck4 birth_qtime_bck4;
    
    year = floor((birth_qtime_bck4-1)/4) + 1985;
    
    if nUntil ~= . then do;
        if year >= nuntil - 2 then top1_is_parent = "";
    end;

    top1_yob = year(top1_dob);

    if in_target then output;
run;
        
* export the data sets to Stata;

proc contents data=interwrk.&file_nm._final_rr;
proc print data=interwrk.&file_nm._final_rr (obs=50);

proc export data=interwrk.&file_nm._final_rr
            file="/interwrk/&file_nm._final_rr"
            dbms=stata replace;
run;
%mend;
        
*%process_top_is_parent(parent);
%process_top_is_parent(acs_parent);
%process_top_is_parent(coworker);
