/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Identifies individuals for which we can determine whether they were ever a parent and then determines whether they ever had a child.

	OUTPUT DATASETS:
	       - interwrk.ever_parent
*********************************************************************************************/

    
data interwrk.ever_parent(keep=pik b_qtime1-b_qtime10 ever_parent nuntil age_fsy age_lsy yob dob first_survey_yr last_survey_yr sex);
    length  ever_parent $1 nuntil 4 pik_partner $9 dob  4 birth_qtime 3 sex $1;
    set interwrk.pikscenacs (in=in_census
                               rename=(acs2001=acs1
                                       acs2002=acs2
                                       acs2003=acs3
                                       acs2004=acs4
                                       acs2005=acs5
                                       acs2006=acs6
                                       acs2007=acs7
                                       acs2008=acs8
                                       acs2009=acs9
                                       acs2010=acs10
                                       acs2011=acs11
                                       acs2012=acs12
                                       acs2013=acs13
                                       acs2014=acs14
                                       acs2015=acs15
                                       acs2016=acs16
                                       acs2017=acs17
                                      )
                );
            
    array b_qtime {10};
    array a_acs {17} acs1-acs17;
        
    if _n_ = 1 then do;
        declare hash p_h (dataset:"interwrk.parentchild",hashexp:16,multidata:"Y");
        p_h.defineKey("pik");
        p_h.defineData("birth_qtime","pik_partner");
        p_h.defineDone();
            
        declare hash pik_dob (dataset:"lehd_t13.icf_us", hashexp:16);
            pik_dob.defineKey('pik');
            pik_dob.defineData('dob','sex');
            pik_dob.defineDone();
    
    end;
    

        * check if parent;
        rc = p_h.find();
        if rc = 0 then do;
            ever_parent="P";
            p_cntr =  0;
        end;    
        do while(rc=0);
            p_cntr = p_cntr + 1;
            * identify set of birth  qtimes;
            if p_cntr <= 10 then do;
                b_qtime{p_cntr}  = birth_qtime;
            end;
        
            rc = p_h.find_next();
        end;


        rc_dob = pik_dob.find();
        if rc_dob = 0  then do;
            yob = year(dob);
        end;
        
  
            * identify the first and last year in which the  individual was surveyed;
            if cen2000 = 1 then first_survey_yr = 2000;
            else if cen2010 = 1 then first_survey_yr=2010;  
                                    
            if cen2010 = 1 then last_survey_yr = 2010;
            else if cen2000 = 1 then last_survey_yr=2000;  
                                    
            do i=1 to 17;
               if a_acs{i} = 1 then do;
                    
                    if first_survey_yr = . then first_survey_yr = i +  2000;
                    else if i < first_survey_yr - 2000 then first_survey_yr = i + 2000;
                    
                    if last_survey_yr  = .  then last_survey_yr = i + 2000;
                    else if  i > last_survey_yr - 2000 then last_survey_yr = i + 2000;
               end;                     
                                    
            end;                                              
              
            * get the individuals DOB;  
            rc_dob = pik_dob.find();
            if rc_dob = 0 and first_survey_yr ~= . then do;
                age_fsy = floor(YRDIF(dob, mdy(6,1,first_survey_yr),'AGE'));
                age_lsy = floor(YRDIF(dob, mdy(6,1,last_survey_yr) ,'AGE'));
                    
                * if observe person for all ages 18-40 and no children;
                if age_fsy ~= . and age_fsy <= 36 and age_lsy >= 40 then do;
                    if ever_parent = "" then ever_parent = "N";
                    NUntil = &last_year. + 10;
                end;
            end;
        
    
        if NUNTIL ~= . then output;
 
run;
            
proc contents data=interwrk.ever_parent;
proc print data=interwrk.ever_parent (obs=100);
        
